@@ -1,9 +1,8 @@
-/**	$MirOS: src/bin/mksh/eval.c,v 1.8 2005/10/25 19:53:27 tg Exp $ */
-/*	$OpenBSD: eval.c,v 1.27 2005/03/30 17:16:37 deraadt Exp $	*/
+/*	$OpenBSD: eval.c,v 1.30 2006/04/10 14:38:59 jaredy Exp $	*/
 
 #include "sh.h"
 
-__RCSID("$MirOS: src/bin/mksh/eval.c,v 1.8 2005/10/25 19:53:27 tg Exp $");
+__RCSID("$MirOS: src/bin/mksh/eval.c,v 1.12 2006/05/10 18:54:09 tg Exp $");
 
 /*
  * string expansion
@@ -37,15 +36,15 @@ typedef struct Expand {
 #define IFS_WS		1	/* have seen IFS white-space */
 #define IFS_NWS		2	/* have seen IFS non-white-space */
 
-static	int	varsub(Expand *, char *, char *, int *, int *);
-static	int	comsub(Expand *, char *);
-static	char   *trimsub(char *, char *, int);
-static	void	glob(char *, XPtrV *, int);
-static	void	globit(XString *, char **, char *, XPtrV *, int);
-static char	*maybe_expand_tilde(char *, XString *, char **, int);
-static	char   *tilde(char *);
-static	char   *homedir(char *);
-static void	alt_expand(XPtrV *, char *, char *, char *, int);
+static int varsub(Expand *, char *, char *, int *, int *);
+static int comsub(Expand *, char *);
+static char *trimsub(char *, char *, int);
+static void glob(char *, XPtrV *, int);
+static void globit(XString *, char **, char *, XPtrV *, int);
+static char *maybe_expand_tilde(char *, XString *, char **, int);
+static char *tilde(char *);
+static char *homedir(char *);
+static void alt_expand(XPtrV *, char *, char *, char *, int);
 
 /* compile and expand word */
 char *
@@ -853,7 +852,7 @@ comsub(Expand *xp, char *cp)
 		int ofd1, pv[2];
 		openpipe(pv);
 		shf = shf_fdopen(pv[0], SHF_RD, NULL);
-		ofd1 = savefd(1, 0);	/* fd 1 may be closed... */
+		ofd1 = savefd(1);
 		if (pv[1] != 1) {
 			ksh_dup2(pv[1], 1, false);
 			close(pv[1]);
@@ -1182,7 +1181,7 @@ homedir(char *name)
 {
 	struct tbl *ap;
 
-	ap = tenter(&homedirs, name, hash(name));
+	ap = ktenter(&homedirs, name, hash(name));
 	if (!(ap->flag & ISSET)) {
 		struct passwd *pw;
 
