@@ -1,9 +1,8 @@
-/**	$MirOS: src/bin/mksh/exec.c,v 1.10 2005/10/25 19:53:27 tg Exp $ */
-/*	$OpenBSD: exec.c,v 1.41 2005/03/30 17:16:37 deraadt Exp $	*/
+/*	$OpenBSD: exec.c,v 1.46 2006/04/10 14:38:59 jaredy Exp $	*/
 
 #include "sh.h"
 
-__RCSID("$MirOS: src/bin/mksh/exec.c,v 1.10 2005/10/25 19:53:27 tg Exp $");
+__RCSID("$MirOS: src/bin/mksh/exec.c,v 1.15 2006/05/10 18:54:10 tg Exp $");
 
 static int	comexec(struct op *, struct tbl *volatile, char **,
 		    int volatile);
@@ -114,9 +113,8 @@ execute(struct op *volatile t,
 	case TPIPE:
 		flags |= XFORK;
 		flags &= ~XEXEC;
-		e->savefd[0] = savefd(0, 0);
-		(void) ksh_dup2(e->savefd[0], 0, false); /* stdin of first */
-		e->savefd[1] = savefd(1, 0);
+		e->savefd[0] = savefd(0);
+		e->savefd[1] = savefd(1);
 		while (t->type == TPIPE) {
 			openpipe(pv);
 			(void) ksh_dup2(pv[1], 1, false); /* stdout of curr */
@@ -161,7 +159,7 @@ execute(struct op *volatile t,
 			sigprocmask(SIG_SETMASK, &omask, NULL);
 			quitenv(NULL);
 			unwind(i);
-			/*NOTREACHED*/
+			/* NOTREACHED */
 		}
 		/* Already have a (live) co-process? */
 		if (coproc.job && coproc.write >= 0)
@@ -171,8 +169,8 @@ execute(struct op *volatile t,
 		coproc_cleanup(true);
 
 		/* do this before opening pipes, in case these fail */
-		e->savefd[0] = savefd(0, 0);
-		e->savefd[1] = savefd(1, 0);
+		e->savefd[0] = savefd(0);
+		e->savefd[1] = savefd(1);
 
 		openpipe(pv);
 		if (pv[0] != 0) {
@@ -396,7 +394,7 @@ comexec(struct op *t, struct tbl *volatile tp, char **ap, volatile int flags)
 
 	/* Deal with the shell builtins builtin, exec and command since
 	 * they can be followed by other commands.  This must be done before
-	 * we know if we should create a local block, which must be done
+	 * we know if we should create a local block which must be done
 	 * before we can do a path search (in case the assignments change
 	 * PATH).
 	 * Odd cases:
@@ -608,7 +606,7 @@ comexec(struct op *t, struct tbl *volatile tp, char **ap, volatile int flags)
 		case LSHELL:
 			quitenv(NULL);
 			unwind(i);
-			/*NOTREACHED*/
+			/* NOTREACHED */
 		default:
 			quitenv(NULL);
 			internal_errorf(1, "CFUNC %d", i);
@@ -689,7 +687,7 @@ shcomexec(char **wp)
 {
 	struct tbl *tp;
 
-	tp = tsearch(&builtins, *wp, hash(*wp));
+	tp = ktsearch(&builtins, *wp, hash(*wp));
 	if (tp == NULL)
 		internal_errorf(1, "shcomexec: %s", *wp);
 	return call_builtin(tp, wp);
@@ -706,11 +704,11 @@ findfunc(const char *name, unsigned int h, int create)
 	struct tbl *tp = NULL;
 
 	for (l = e->loc; l; l = l->next) {
-		tp = tsearch(&l->funs, name, h);
+		tp = ktsearch(&l->funs, name, h);
 		if (tp)
 			break;
 		if (!l->next && create) {
-			tp = tenter(&l->funs, name, h);
+			tp = ktenter(&l->funs, name, h);
 			tp->flag = DEFINED;
 			tp->type = CFUNC;
 			tp->val.t = NULL;
@@ -752,7 +750,7 @@ define(const char *name, struct op *t)
 	}
 
 	if (t == NULL) {		/* undefine */
-		tdelete(tp);
+		ktdelete(tp);
 		return was_set ? 0 : 1;
 	}
 
@@ -785,7 +783,7 @@ builtin(const char *name, int (*func) (char **))
 			break;
 	}
 
-	tp = tenter(&builtins, name, hash(name));
+	tp = ktenter(&builtins, name, hash(name));
 	tp->flag = DEFINED | flag;
 	tp->type = CSHELL;
 	tp->val.f = func;
@@ -811,7 +809,7 @@ findcom(const char *name, int flags)
 		flags &= ~FC_FUNC;
 		goto Search;
 	}
-	tbi = (flags & FC_BI) ? tsearch(&builtins, name, h) : NULL;
+	tbi = (flags & FC_BI) ? ktsearch(&builtins, name, h) : NULL;
 	/* POSIX says special builtins first, then functions, then
 	 * POSIX regular builtins, then search path...
 	 */
@@ -833,7 +831,7 @@ findcom(const char *name, int flags)
 	if (!tp && (flags & FC_UNREGBI) && tbi)
 		tp = tbi;
 	if (!tp && (flags & FC_PATH) && !(flags & FC_DEFPATH)) {
-		tp = tsearch(&taliases, name, h);
+		tp = ktsearch(&taliases, name, h);
 		if (tp && (tp->flag & ISSET) && eaccess(tp->val.s, X_OK) != 0) {
 			if (tp->flag & ALLOC) {
 				tp->flag &= ~ALLOC;
@@ -848,7 +846,7 @@ findcom(const char *name, int flags)
 	    (flags & FC_PATH)) {
 		if (!tp) {
 			if (insert && !(flags & FC_DEFPATH)) {
-				tp = tenter(&taliases, name, h);
+				tp = ktenter(&taliases, name, h);
 				tp->type = CTALIAS;
 			} else {
 				tp = &temp;
@@ -888,7 +886,7 @@ flushcom(int all)	/* just relative or all */
 	struct tbl *tp;
 	struct tstate ts;
 
-	for (twalk(&ts, &taliases); (tp = tnext(&ts)) != NULL; )
+	for (ktwalk(&ts, &taliases); (tp = ktnext(&ts)) != NULL; )
 		if ((tp->flag&ISSET) && (all || tp->val.s[0] != '/')) {
 			if (tp->flag&ALLOC) {
 				tp->flag &= ~(ALLOC|ISSET);
@@ -1092,7 +1090,7 @@ iosetup(struct ioword *iop, struct tbl *tp)
 			 * is 2; also means we can't lose the fd (eg, both
 			 * dup2 below and dup2 in restfd() failing).
 			 */
-			e->savefd[iop->unit] = savefd(iop->unit, 1);
+			e->savefd[iop->unit] = savefd(iop->unit);
 	}
 
 	if (do_close)
@@ -1170,7 +1168,7 @@ herein(const char *content, int sub)
 		s = pushs(SSTRING, ATEMP);
 		s->start = s->str = content;
 		source = s;
-		if (yylex(ONEWORD) != LWORD)
+		if (yylex(ONEWORD|HEREDOC) != LWORD)
 			internal_errorf(1, "herein: yylex");
 		source = osource;
 		shf_puts(evalstr(yylval.cp, 0), shf);
@@ -1228,7 +1226,7 @@ struct select_menu_info {
 	char	*const *args;
 	int	arg_width;
 	int	num_width;
-} info;
+};
 
 static char *select_fmt_entry(void *arg, int i, char *buf, int buflen);
 
