@@ -1,12 +1,11 @@
-/**	$MirOS: src/bin/mksh/funcs.c,v 1.23 2005/10/25 19:53:27 tg Exp $ */
-/*	$OpenBSD: c_ksh.c,v 1.27 2005/03/30 17:16:37 deraadt Exp $	*/
-/*	$OpenBSD: c_sh.c,v 1.31 2005/10/08 18:07:31 otto Exp $	*/
+/*	$OpenBSD: c_ksh.c,v 1.29 2006/03/12 00:26:58 deraadt Exp $	*/
+/*	$OpenBSD: c_sh.c,v 1.35 2006/04/10 14:38:59 jaredy Exp $	*/
 /*	$OpenBSD: c_test.c,v 1.17 2005/03/30 17:16:37 deraadt Exp $	*/
-/*	$OpenBSD: c_ulimit.c,v 1.14 2005/03/30 17:16:37 deraadt Exp $	*/
+/*	$OpenBSD: c_ulimit.c,v 1.15 2006/03/12 00:26:58 deraadt Exp $	*/
 
 #include "sh.h"
 
-__RCSID("$MirOS: src/bin/mksh/funcs.c,v 1.23 2005/10/25 19:53:27 tg Exp $");
+__RCSID("$MirOS: src/bin/mksh/funcs.c,v 1.28 2006/07/03 12:16:30 tg Exp $");
 
 int
 c_cd(char **wp)
@@ -23,7 +22,7 @@ c_cd(char **wp)
 	int phys_path;
 	char *cdpath;
 
-	while ((optc = ksh_getopt(wp, &builtin_opt, "LP")) != EOF)
+	while ((optc = ksh_getopt(wp, &builtin_opt, "LP")) != -1)
 		switch (optc) {
 		case 'L':
 			physical = 0;
@@ -158,7 +157,7 @@ c_pwd(char **wp)
 	int physical = Flag(FPHYSICAL);
 	char *p;
 
-	while ((optc = ksh_getopt(wp, &builtin_opt, "LP")) != EOF)
+	while ((optc = ksh_getopt(wp, &builtin_opt, "LP")) != -1)
 		switch (optc) {
 		case 'L':
 			physical = 0;
@@ -240,7 +239,7 @@ c_print(char **wp)
 	} else {
 		int optc;
 		const char *opts = "Rnprsu,";
-		while ((optc = ksh_getopt(wp, &builtin_opt, opts)) != EOF)
+		while ((optc = ksh_getopt(wp, &builtin_opt, opts)) != -1)
 			switch (optc) {
 			case 'R': /* fake BSD echo command */
 				flags |= PO_PMINUSMINUS;
@@ -348,7 +347,7 @@ c_print(char **wp)
 
 		/* Ensure we aren't killed by a SIGPIPE while writing to
 		 * a coprocess.  at&t ksh doesn't seem to do this (seems
-		 * to just check that the co-process is alive, which is
+		 * to just check that the co-process is alive which is
 		 * not enough).
 		 */
 		if (coproc.write >= 0 && coproc.write == fd) {
@@ -391,7 +390,7 @@ c_whence(char **wp)
 	int fcflags;
 	const char *opts = iam_whence ? "pv" : "pvV";
 
-	while ((optc = ksh_getopt(wp, &builtin_opt, opts)) != EOF)
+	while ((optc = ksh_getopt(wp, &builtin_opt, opts)) != -1)
 		switch (optc) {
 		case 'p':
 			pflag = 1;
@@ -425,9 +424,9 @@ c_whence(char **wp)
 	while ((vflag || ret == 0) && (id = *wp++) != NULL) {
 		tp = NULL;
 		if ((iam_whence || vflag) && !pflag)
-			tp = tsearch(&keywords, id, hash(id));
+			tp = ktsearch(&keywords, id, hash(id));
 		if (!tp && !pflag) {
-			tp = tsearch(&aliases, id, hash(id));
+			tp = ktsearch(&aliases, id, hash(id));
 			if (tp && !(tp->flag & ISSET))
 				tp = NULL;
 		}
@@ -542,7 +541,7 @@ c_typeset(char **wp)
 
 	fieldstr = basestr = NULL;
 	builtin_opt.flags |= GF_PLUSOPT;
-	/* at&t ksh seems to have 0-9 as options, which are multiplied
+	/* at&t ksh seems to have 0-9 as options which are multiplied
 	 * to get a number that is used with -L, -R, -Z or -i (eg, -1R2
 	 * sets right justify in a field of 12).  This allows options
 	 * to be grouped in an order (eg, -Lu12), but disallows -i8 -L3 and
@@ -550,7 +549,7 @@ c_typeset(char **wp)
 	 * Here, the number must follow the RLZi option, but is optional
 	 * (see the # kludge in ksh_getopt()).
 	 */
-	while ((optc = ksh_getopt(wp, &builtin_opt, opts)) != EOF) {
+	while ((optc = ksh_getopt(wp, &builtin_opt, opts)) != -1) {
 		flag = 0;
 		switch (optc) {
 		case 'L':
@@ -693,7 +692,7 @@ c_typeset(char **wp)
 	flag = fset | fclr; /* no difference at this point.. */
 	if (func) {
 		for (l = e->loc; l; l = l->next) {
-			for (p = tsort(&l->funs); (vp = *p++); ) {
+			for (p = ktsort(&l->funs); (vp = *p++); ) {
 				if (flag && (vp->flag & flag) == 0)
 					continue;
 				if (thing == '-')
@@ -706,7 +705,7 @@ c_typeset(char **wp)
 		}
 	} else {
 		for (l = e->loc; l; l = l->next) {
-			for (p = tsort(&l->vars); (vp = *p++); ) {
+			for (p = ktsort(&l->vars); (vp = *p++); ) {
 				struct tbl *tvp;
 				int any_set = 0;
 				/*
@@ -818,7 +817,7 @@ c_alias(char **wp)
 	int optc;
 
 	builtin_opt.flags |= GF_PLUSOPT;
-	while ((optc = ksh_getopt(wp, &builtin_opt, "dprtUx")) != EOF) {
+	while ((optc = ksh_getopt(wp, &builtin_opt, "dprtUx")) != -1) {
 		prefix = builtin_opt.info & GI_PLUS ? '+' : '-';
 		switch (optc) {
 		case 'd':
@@ -875,7 +874,7 @@ c_alias(char **wp)
 	if (*wp == NULL) {
 		struct tbl *ap, **p;
 
-		for (p = tsort(t); (ap = *p++) != NULL; )
+		for (p = ktsort(t); (ap = *p++) != NULL; )
 			if ((ap->flag & (ISSET|xflag)) == (ISSET|xflag)) {
 				if (pflag)
 					shf_puts("alias ", shl_stdout);
@@ -899,7 +898,7 @@ c_alias(char **wp)
 			alias = str_nsave(alias, val++ - alias, ATEMP);
 		h = hash(alias);
 		if (val == NULL && !tflag && !xflag) {
-			ap = tsearch(t, alias, h);
+			ap = ktsearch(t, alias, h);
 			if (ap != NULL && (ap->flag&ISSET)) {
 				if (pflag)
 					shf_puts("alias ", shl_stdout);
@@ -915,7 +914,7 @@ c_alias(char **wp)
 			}
 			continue;
 		}
-		ap = tenter(t, alias, h);
+		ap = ktenter(t, alias, h);
 		ap->type = tflag ? CTALIAS : CALIAS;
 		/* Are we setting the value or just some flags? */
 		if ((val && !tflag) || (!val && tflag && !Uflag)) {
@@ -952,7 +951,7 @@ c_unalias(char **wp)
 	int rv = 0, all = 0;
 	int optc;
 
-	while ((optc = ksh_getopt(wp, &builtin_opt, "adt")) != EOF)
+	while ((optc = ksh_getopt(wp, &builtin_opt, "adt")) != -1)
 		switch (optc) {
 		case 'a':
 			all = 1;
@@ -969,7 +968,7 @@ c_unalias(char **wp)
 	wp += builtin_opt.optind;
 
 	for (; *wp != NULL; wp++) {
-		ap = tsearch(t, *wp, hash(*wp));
+		ap = ktsearch(t, *wp, hash(*wp));
 		if (ap == NULL) {
 			rv = 1;	/* POSIX */
 			continue;
@@ -984,7 +983,7 @@ c_unalias(char **wp)
 	if (all) {
 		struct tstate ts;
 
-		for (twalk(&ts, t); (ap = tnext(&ts)); ) {
+		for (ktwalk(&ts, t); (ap = ktnext(&ts)); ) {
 			if (ap->flag&ALLOC) {
 				ap->flag &= ~(ALLOC|ISSET);
 				afree((void*)ap->val.s, APERM);
@@ -1022,7 +1021,7 @@ c_jobs(char **wp)
 	int nflag = 0;
 	int rv = 0;
 
-	while ((optc = ksh_getopt(wp, &builtin_opt, "lpnz")) != EOF)
+	while ((optc = ksh_getopt(wp, &builtin_opt, "lpnz")) != -1)
 		switch (optc) {
 		case 'l':
 			flag = 1;
@@ -1108,7 +1107,8 @@ c_kill(char **wp)
 	int i, n, rv, sig;
 
 	/* assume old style options if -digits or -UPPERCASE */
-	if ((p = wp[1]) && *p == '-' && (digit(p[1]) || isupper(p[1]))) {
+	if ((p = wp[1]) && *p == '-' && (digit(p[1]) ||
+	    isupper((unsigned char)p[1]))) {
 		if (!(t = gettrap(p + 1, true))) {
 			bi_errorf("bad signal '%s'", p + 1);
 			return 1;
@@ -1117,7 +1117,7 @@ c_kill(char **wp)
 	} else {
 		int optc;
 
-		while ((optc = ksh_getopt(wp, &builtin_opt, "ls:")) != EOF)
+		while ((optc = ksh_getopt(wp, &builtin_opt, "ls:")) != -1)
 			switch (optc) {
 			case 'l':
 				lflag = 1;
@@ -1314,7 +1314,7 @@ c_bind(char **wp)
 	int optc, rv = 0, macro = 0, list = 0;
 	char *cp;
 
-	while ((optc = ksh_getopt(wp, &builtin_opt, "lm")) != EOF)
+	while ((optc = ksh_getopt(wp, &builtin_opt, "lm")) != -1)
 		switch (optc) {
 		case 'l':
 			list = 1;
@@ -1419,7 +1419,7 @@ c_umask(char **wp)
 	mode_t old_umask;
 	int optc;
 
-	while ((optc = ksh_getopt(wp, &builtin_opt, "S")) != EOF)
+	while ((optc = ksh_getopt(wp, &builtin_opt, "S")) != -1)
 		switch (optc) {
 		case 'S':
 			symbolic = 1;
@@ -1614,7 +1614,7 @@ c_read(char **wp)
 	char *xp = NULL;
 	static char REPLY[] = "REPLY";
 
-	while ((optc = ksh_getopt(wp, &builtin_opt, "prsu,")) != EOF)
+	while ((optc = ksh_getopt(wp, &builtin_opt, "prsu,")) != -1)
 		switch (optc) {
 		case 'p':
 			if ((fd = coproc_getfd(R_OK, &emsg)) < 0) {
@@ -1902,7 +1902,7 @@ c_exitreturn(char **wp)
 
 	quitenv(NULL);	/* get rid of any i/o redirections */
 	unwind(how);
-	/*NOTREACHED*/
+	/* NOTREACHED */
 	return 0;
 }
 
@@ -1956,7 +1956,7 @@ c_brkcont(char **wp)
 	}
 
 	unwind(*wp[0] == 'b' ? LBREAK : LCONTIN);
-	/*NOTREACHED*/
+	/* NOTREACHED */
 }
 
 int
@@ -2001,7 +2001,7 @@ c_unset(char **wp)
 	int optc, unset_var = 1;
 	int ret = 0;
 
-	while ((optc = ksh_getopt(wp, &builtin_opt, "fv")) != EOF)
+	while ((optc = ksh_getopt(wp, &builtin_opt, "fv")) != -1)
 		switch (optc) {
 		case 'f':
 			unset_var = 0;
@@ -2142,7 +2142,7 @@ timex_hook(struct op *t, char **volatile *app)
 
 	ksh_getopt_reset(&opt, 0);
 	opt.optind = 0;	/* start at the start */
-	while ((optc = ksh_getopt(wp, &opt, ":p")) != EOF)
+	while ((optc = ksh_getopt(wp, &opt, ":p")) != -1)
 		switch (optc) {
 		case 'p':
 			t->str[0] |= TF_POSIX;
@@ -2194,7 +2194,7 @@ c_mknod(char **wp)
 	void *set = NULL;
 	mode_t mode = 0, oldmode = 0;
 
-	while ((optc = ksh_getopt(wp, &builtin_opt, "m:")) != EOF) {
+	while ((optc = ksh_getopt(wp, &builtin_opt, "m:")) != -1) {
 		switch (optc) {
 		case 'm':
 			set = setmode(builtin_opt.optarg);
@@ -2903,7 +2903,7 @@ c_ulimit(char **wp)
 		*p = '\0';
 	}
 	what = 'f';
-	while ((optc = ksh_getopt(wp, &builtin_opt, opts)) != EOF)
+	while ((optc = ksh_getopt(wp, &builtin_opt, opts)) != -1)
 		switch (optc) {
 		case 'H':
 			how = HARD;
