@@ -1,10 +1,9 @@
-/**	$MirOS: src/bin/mksh/histrap.c,v 1.12 2005/10/25 19:53:28 tg Exp $ */
-/*	$OpenBSD: history.c,v 1.31 2005/07/31 16:12:52 espie Exp $	*/
+/*	$OpenBSD: history.c,v 1.34 2006/03/17 16:30:13 millert Exp $	*/
 /*	$OpenBSD: trap.c,v 1.22 2005/03/30 17:16:37 deraadt Exp $	*/
 
 #include "sh.h"
 
-__RCSID("$MirOS: src/bin/mksh/histrap.c,v 1.12 2005/10/25 19:53:28 tg Exp $");
+__RCSID("$MirOS: src/bin/mksh/histrap.c,v 1.15 2006/05/10 18:54:10 tg Exp $");
 
 static int	histfd;
 static int	hsize;
@@ -26,7 +25,6 @@ static char   **hist_get_oldest(void);
 static void	histbackup(void);
 
 static char   **current;	/* current position in history[] */
-static int	curpos;		/* current index in history[] */
 static char    *hname;		/* current name of history file */
 static int	hstarted;	/* set after hist_init() called */
 static Source	*hist_source;
@@ -65,7 +63,7 @@ c_fc(char **wp)
 	}
 
 	while ((optc = ksh_getopt(wp, &builtin_opt,
-	    "e:glnrs0,1,2,3,4,5,6,7,8,9,")) != EOF)
+	    "e:glnrs0,1,2,3,4,5,6,7,8,9,")) != -1)
 		switch (optc) {
 		case 'e':
 			p = builtin_opt.optarg;
@@ -433,12 +431,6 @@ histpos(void)
 	return current;
 }
 
-int
-histN(void)
-{
-	return curpos;
-}
-
 int
 histnum(int n)
 {
@@ -446,11 +438,9 @@ histnum(int n)
 
 	if (n < 0 || n >= last) {
 		current = histptr;
-		curpos = last;
 		return last;
 	} else {
 		current = &history[n];
-		curpos = n;
 		return n;
 	}
 }
@@ -663,7 +653,9 @@ hist_init(Source *s)
 	if ((fd = open(hname, O_RDWR|O_CREAT|O_APPEND, 0600)) < 0)
 		return;
 
-	histfd = savefd(fd, 0);
+	histfd = savefd(fd);
+	if (histfd != fd)
+		close(fd);
 
 	(void) flock(histfd, LOCK_EX);
 
