@@ -1,15 +1,14 @@
-/**	$MirOS: src/bin/mksh/main.c,v 1.30 2005/10/25 21:11:26 tg Exp $ */
-/*	$OpenBSD: main.c,v 1.38 2005/03/30 17:16:37 deraadt Exp $	*/
-/*	$OpenBSD: tty.c,v 1.8 2005/03/30 17:16:37 deraadt Exp $	*/
-/*	$OpenBSD: io.c,v 1.21 2005/03/30 17:16:37 deraadt Exp $	*/
-/*	$OpenBSD: table.c,v 1.11 2005/03/30 17:16:37 deraadt Exp $	*/
+/*	$OpenBSD: main.c,v 1.41 2006/04/10 14:38:59 jaredy Exp $	*/
+/*	$OpenBSD: tty.c,v 1.9 2006/03/14 22:08:01 deraadt Exp $	*/
+/*	$OpenBSD: io.c,v 1.22 2006/03/17 16:30:13 millert Exp $	*/
+/*	$OpenBSD: table.c,v 1.12 2005/12/11 20:31:21 otto Exp $	*/
 
 #define	EXTERN				/* define EXTERNs in sh.h */
 #include "sh.h"
 
-__RCSID("$MirOS: src/bin/mksh/main.c,v 1.30 2005/10/25 21:11:26 tg Exp $");
+__RCSID("$MirOS: src/bin/mksh/main.c,v 1.40 2006/07/03 12:16:30 tg Exp $");
 
-#define	MKSH_VERSION	"@(#)MIRBSD KSH R25 2005/10/25"
+#define	MKSH_VERSION	"@(#)MIRBSD KSH R27 2006/07/03"
 
 extern char **environ;
 
@@ -100,15 +99,15 @@ main(int argc, char *argv[])
 	coproc_init();
 
 	/* set up variable and command dictionaries */
-	tinit(&taliases, APERM, 0);
-	tinit(&aliases, APERM, 0);
-	tinit(&homedirs, APERM, 0);
+	ktinit(&taliases, APERM, 0);
+	ktinit(&aliases, APERM, 0);
+	ktinit(&homedirs, APERM, 0);
 
 	/* define shell keywords */
 	initkeywords();
 
 	/* define built-in commands */
-	tinit(&builtins, APERM, 64); /* must be 2^n (currently 40 builtins) */
+	ktinit(&builtins, APERM, 64); /* must be 2^n (currently 40 builtins) */
 	for (i = 0; shbuiltins[i].name != NULL; i++)
 		builtin(shbuiltins[i].name, shbuiltins[i].func);
 	for (i = 0; kshbuiltins[i].name != NULL; i++)
@@ -295,11 +294,12 @@ main(int argc, char *argv[])
 	}
 	if (Flag(FPRIVILEGED))
 		include("/etc/suid_profile", 0, NULL, 1);
-	else {
+	else if (Flag(FTALKING)) {
 		char *env_file;
 
 		/* include $ENV */
-		env_file = substitute(str_val(global("ENV")), DOTILDE);
+		env_file = substitute(substitute("${ENV:-~/.mkshrc}", 0),
+		    DOTILDE);
 		if (*env_file != '\0')
 			include(env_file, 0, NULL, 1);
 	}
@@ -482,7 +482,7 @@ shell(Source * volatile s, volatile int toplevel)
 				really_exit = 1;
 				s->type = SSTDIN;
 			} else {
-				/* this for POSIX, which says EXIT traps
+				/* this for POSIX which says EXIT traps
 				 * shall be taken in the environment
 				 * immediately after the last command
 				 * executed.
@@ -660,14 +660,6 @@ remove_temps(struct temp *tp)
 		}
 }
 
-void
-aerror(Area *ap __attribute__((unused)), const char *msg)
-{
-	internal_errorf(1, "alloc: %s", msg);
-	errorf(null); /* this is never executed - keeps gcc quiet */
-	/*NOTREACHED*/
-}
-
 /* Initialize tty_fd.  Used for saving/reseting tty modes upon
  * foreground job completion and for setting up tty process group.
  */
@@ -684,12 +676,9 @@ tty_init(int init_ttystate)
 	tty_devtty = 1;
 
 	if ((tfd = open("/dev/tty", O_RDWR, 0)) < 0) {
-		if (tfd < 0) {
-			tty_devtty = 0;
-			warningf(false,
-			    "No controlling tty (open /dev/tty: %s)",
-			    strerror(errno));
-		}
+		tty_devtty = 0;
+		warningf(false, "No controlling tty (open /dev/tty: %s)",
+		    strerror(errno));
 	}
 	if (tfd < 0) {
 		do_close = 0;
@@ -886,7 +875,7 @@ ksh_dup2(int ofd, int nfd, int errok)
  * set close-on-exec flag.
  */
 int
-savefd(int fd, int noclose)
+savefd(int fd)
 {
 	int nfd;
 
@@ -898,8 +887,6 @@ savefd(int fd, int noclose)
 			else
 				errorf("too many files open in shell");
 		}
-		if (!noclose)
-			close(fd);
 	} else
 		nfd = fd;
 	fcntl(nfd, F_SETFD, FD_CLOEXEC);
@@ -922,10 +909,16 @@ restfd(int fd, int ofd)
 void
 openpipe(int *pv)
 {
-	if (pipe(pv) < 0)
+	int lpv[2];
+
+	if (pipe(lpv) < 0)
 		errorf("can't create pipe - try again");
-	pv[0] = savefd(pv[0], 0);
-	pv[1] = savefd(pv[1], 0);
+	pv[0] = savefd(lpv[0]);
+	if (pv[0] != lpv[0])
+		close(lpv[0]);
+	pv[1] = savefd(lpv[1]);
+	if (pv[1] != lpv[1])
+		close(lpv[1]);
 }
 
 void
@@ -943,7 +936,7 @@ check_fd(char *name, int mode, const char **emsgp)
 {
 	int fd, fl;
 
-	if (isdigit(name[0]) && !name[1]) {
+	if (isdigit((unsigned char)name[0]) && !name[1]) {
 		fd = name[0] - '0';
 		if ((fl = fcntl(fd = name[0] - '0', F_GETFL, 0)) < 0) {
 			if (emsgp)
@@ -1095,7 +1088,7 @@ hash(const char *n)
 }
 
 void
-tinit(struct table *tp, Area *ap, int tsize)
+ktinit(struct table *tp, Area *ap, int tsize)
 {
 	tp->areap = ap;
 	tp->tbls = NULL;
@@ -1140,7 +1133,7 @@ texpand(struct table *tp, int nsize)
 /* name to enter */
 /* hash(n) */
 struct tbl *
-tsearch(struct table *tp, const char *n, unsigned int h)
+ktsearch(struct table *tp, const char *n, unsigned int h)
 {
 	struct tbl **pp, *p;
 
@@ -1163,7 +1156,7 @@ tsearch(struct table *tp, const char *n, unsigned int h)
 /* name to enter */
 /* hash(n) */
 struct tbl *
-tenter(struct table *tp, const char *n, unsigned int h)
+ktenter(struct table *tp, const char *n, unsigned int h)
 {
 	struct tbl **pp, *p;
 	int len;
@@ -1201,20 +1194,20 @@ Search:
 }
 
 void
-tdelete(struct tbl *p)
+ktdelete(struct tbl *p)
 {
 	p->flag = 0;
 }
 
 void
-twalk(struct tstate *ts, struct table *tp)
+ktwalk(struct tstate *ts, struct table *tp)
 {
 	ts->left = tp->size;
 	ts->next = tp->tbls;
 }
 
 struct tbl *
-tnext(struct tstate *ts)
+ktnext(struct tstate *ts)
 {
 	while (--ts->left >= 0) {
 		struct tbl *p = *ts->next++;
@@ -1231,7 +1224,7 @@ tnamecmp(void *p1, void *p2)
 }
 
 struct tbl **
-tsort(struct table *tp)
+ktsort(struct table *tp)
 {
 	int i;
 	struct tbl **p, **sp, **dp;
