@@ -1,24 +1,17 @@
-/**	$MirOS: src/bin/mksh/sh.h,v 1.21 2005/10/25 19:53:28 tg Exp $ */
-/*	$OpenBSD: sh.h,v 1.28 2005/10/04 20:35:11 otto Exp $	*/
-/*	$OpenBSD: shf.h,v 1.5 2005/03/30 17:16:37 deraadt Exp $	*/
-/*	$OpenBSD: table.h,v 1.6 2004/12/18 20:55:52 millert Exp $	*/
+/*	$OpenBSD: sh.h,v 1.29 2005/12/11 18:53:51 deraadt Exp $	*/
+/*	$OpenBSD: shf.h,v 1.6 2005/12/11 18:53:51 deraadt Exp $	*/
+/*	$OpenBSD: table.h,v 1.7 2005/12/11 20:31:21 otto Exp $	*/
 /*	$OpenBSD: tree.h,v 1.10 2005/03/28 21:28:22 deraadt Exp $	*/
 /*	$OpenBSD: expand.h,v 1.6 2005/03/30 17:16:37 deraadt Exp $	*/
-/*	$OpenBSD: lex.h,v 1.9 2004/12/18 21:04:52 millert Exp $	*/
-/*	$OpenBSD: proto.h,v 1.27 2005/10/06 06:39:36 otto Exp $	*/
+/*	$OpenBSD: lex.h,v 1.10 2005/09/11 18:02:27 otto Exp $	*/
+/*	$OpenBSD: proto.h,v 1.30 2006/03/17 16:30:13 millert Exp $	*/
 /*	$OpenBSD: c_test.h,v 1.4 2004/12/20 11:34:26 otto Exp $	*/
 /*	$OpenBSD: tty.h,v 1.5 2004/12/20 11:34:26 otto Exp $	*/
 
-#if defined(__INTERIX) && !defined(_ALL_SOURCE)
-#define _ALL_SOURCE
-#endif
+#define	MKSH_SH_H_ID	"$MirOS: src/bin/mksh/sh.h,v 1.27 2006/06/21 19:35:38 tg Exp $"
 
 #include <sys/param.h>
 
-#if defined(__gnu_linux__) && !defined(_POSIX_SOURCE)
-#define _POSIX_SOURCE
-#endif
-
 #ifndef __RCSID
 #define	__RCSID(x)	static const char __rcsid[] __attribute__((used)) = (x)
 #endif
@@ -226,7 +219,6 @@ EXTERN	char shell_flags [FNFLAGS];
 EXTERN	char	null [] I__("");	/* null value for variable */
 EXTERN	char	space [] I__(" ");
 EXTERN	char	newline [] I__("\n");
-EXTERN	char	slash [] I__("/");
 
 enum temp_type {
 	TT_HEREDOC_EXP,	/* expanded heredoc */
@@ -584,7 +576,7 @@ struct block {
 #define BF_DOGETOPTS	BIT(0)	/* save/restore getopts state */
 
 /*
- * Used by twalk() and tnext() routines.
+ * Used by ktwalk() and ktnext() routines.
  */
 struct tstate {
 	int left;
@@ -954,6 +946,7 @@ typedef union {
 #define CMDWORD		BIT(8)	/* parsing simple command (alias related) */
 #define HEREDELIM	BIT(9)	/* parsing <<,<<- delimiter */
 #define	LQCHAR		BIT(10)	/* source string contains QCHAR */
+#define	HEREDOC		BIT(11)	/* parsing a here document */
 
 #define	HERES	10		/* max << in line */
 
@@ -1046,7 +1039,6 @@ int	c_fc(char **);
 void	sethistsize(int);
 void	sethistfile(const char *);
 char **	histpos(void);
-int	histN(void);
 int	histnum(int);
 int	findhist(int, int, const char *, int);
 int	findhistrel(const char *);
@@ -1098,7 +1090,6 @@ void	newenv(int);
 void	quitenv(struct shf *);
 void	cleanup_parents_env(void);
 void	cleanup_proc_env(void);
-void	aerror(Area *, const char *) __attribute__((__noreturn__));
 void	errorf(const char *, ...)
 	    __attribute__((__noreturn__, __format__ (printf, 1, 2)));
 void	warningf(int, const char *, ...)
@@ -1115,7 +1106,7 @@ void	shprintf(const char *, ...)
 int	can_seek(int);
 void	initio(void);
 int	ksh_dup2(int, int, int);
-int	savefd(int, int);
+int	savefd(int);
 void	restfd(int, int);
 void	openpipe(int *);
 void	closepipe(int *);
@@ -1128,13 +1119,13 @@ int	coproc_getfd(int, const char **);
 void	coproc_cleanup(int);
 struct temp *maketemp(Area *, Temp_type, struct temp **);
 unsigned int	hash(const char *);
-void		tinit(struct table *, Area *, int);
-struct tbl *	tsearch(struct table *, const char *, unsigned int);
-struct tbl *	tenter(struct table *, const char *, unsigned int);
-void		tdelete(struct tbl *);
-void		twalk(struct tstate *, struct table *);
-struct tbl *	tnext(struct tstate *);
-struct tbl **	tsort(struct table *);
+void		ktinit(struct table *, Area *, int);
+struct tbl *	ktsearch(struct table *, const char *, unsigned int);
+struct tbl *	ktenter(struct table *, const char *, unsigned int);
+void		ktdelete(struct tbl *);
+void		ktwalk(struct tstate *, struct table *);
+struct tbl *	ktnext(struct tstate *);
+struct tbl **	ktsort(struct table *);
 /* misc.c */
 void	setctypes(const char *, int);
 void	initctypes(void);
@@ -1174,9 +1165,7 @@ struct shf *shf_sopen(char *, int, int, struct shf *);
 int	shf_close(struct shf *);
 int	shf_fdclose(struct shf *);
 char *	shf_sclose(struct shf *);
-int	shf_finish(struct shf *);
 int	shf_flush(struct shf *);
-int	shf_seek(struct shf *, off_t, int);
 int	shf_read(char *, int, struct shf *);
 char *	shf_getse(char *, int, struct shf *);
 int	shf_getchar(struct shf *s);
@@ -1296,3 +1285,11 @@ extern void	tty_close(void);
 #define	HAVE_ARC4RANDOM	1
 #endif
 #endif
+
+#ifndef HAVE_ARC4RANDOM_PUSH
+#if defined(__MirBSD__) && (MirBSD >= 0x07AD)
+#define HAVE_ARC4RANDOM_PUSH 1
+#else
+#define HAVE_ARC4RANDOM_PUSH 0
+#endif
+#endif
