@@ -1,9 +1,8 @@
-/**	$MirOS: src/bin/mksh/syn.c,v 1.3 2005/10/08 19:31:00 tg Exp $ */
-/*	$OpenBSD: syn.c,v 1.22 2005/03/30 17:16:37 deraadt Exp $	*/
+/*	$OpenBSD: syn.c,v 1.27 2006/04/10 14:38:59 jaredy Exp $	*/
 
 #include "sh.h"
 
-__RCSID("$MirOS: src/bin/mksh/syn.c,v 1.3 2005/10/08 19:31:00 tg Exp $");
+__RCSID("$MirOS: src/bin/mksh/syn.c,v 1.7 2006/05/10 18:54:13 tg Exp $");
 
 struct nesting_state {
 	int	start_token;	/* token than began nesting (eg, FOR) */
@@ -243,7 +242,7 @@ get_command(int cf)
 				break;
 
 			case '(':
-				/* Check for "> foo (echo hi)", which at&t ksh
+				/* Check for "> foo (echo hi)" which at&t ksh
 				 * allows (not POSIX, but not disallowed)
 				 */
 				afree(t, ATEMP);
@@ -660,10 +659,10 @@ initkeywords(void)
 	struct tokeninfo const *tt;
 	struct tbl *p;
 
-	tinit(&keywords, APERM, 32); /* must be 2^n (currently 20 keywords) */
+	ktinit(&keywords, APERM, 32); /* must be 2^n (currently 20 keywords) */
 	for (tt = tokentab; tt->name; tt++) {
 		if (tt->reserved) {
-			p = tenter(&keywords, tt->name, hash(tt->name));
+			p = ktenter(&keywords, tt->name, hash(tt->name));
 			p->flag |= DEFINED|ISSET;
 			p->type = CKEYWD;
 			p->val.i = tt->val;
@@ -694,7 +693,7 @@ syntaxerr(const char *what)
 		}
 		/* don't quote the EOF */
 		yyerror("syntax error: unexpected EOF\n");
-		/*NOTREACHED*/
+		/* NOTREACHED */
 
 	case LWORD:
 		s = snptreef(NULL, 32, "%S", yylval.cp);
@@ -776,14 +775,12 @@ compile(Source *s)
 static int
 assign_command(char *s)
 {
-	char c = *s;
-
 	if (!*s)
 		return 0;
-	return (c == 'a' && strcmp(s, "alias") == 0) ||
-	    (c == 'e' && strcmp(s, "export") == 0) ||
-	    (c == 'r' && strcmp(s, "readonly") == 0) ||
-	    (c == 't' && strcmp(s, "typeset") == 0);
+	return (strcmp(s, "alias") == 0) ||
+	    (strcmp(s, "export") == 0) ||
+	    (strcmp(s, "readonly") == 0) ||
+	    (strcmp(s, "typeset") == 0);
 }
 
 /* Check if we are in the middle of reading an alias */
