@@ -1,9 +1,8 @@
-/**	$MirOS: src/bin/mksh/var.c,v 1.10 2005/10/25 19:53:29 tg Exp $ */
-/*	$OpenBSD: var.c,v 1.27 2005/10/08 18:02:59 otto Exp $	*/
+/*	$OpenBSD: var.c,v 1.30 2006/05/21 18:40:39 otto Exp $	*/
 
 #include "sh.h"
 
-__RCSID("$MirOS: src/bin/mksh/var.c,v 1.10 2005/10/25 19:53:29 tg Exp $");
+__RCSID("$MirOS: src/bin/mksh/var.c,v 1.20 2006/07/03 12:16:31 tg Exp $");
 
 /*
  * Variables
@@ -14,8 +13,8 @@ __RCSID("$MirOS: src/bin/mksh/var.c,v 1.10 2005/10/25 19:53:29 tg Exp $");
  * otherwise, (val.s + type) contains string value.
  * if (flag&EXPORT), val.s contains "name=value" for E-Z exporting.
  */
-static	struct tbl vtemp;
-static	struct table specials;
+static struct tbl vtemp;
+static struct table specials;
 static char	*formatstr(struct tbl *, const char *);
 static void	export(struct tbl *, const char *);
 static int	special(const char *);
@@ -46,8 +45,8 @@ newblock(void)
 		l->argv = e->loc->argv;
 	}
 	l->exit = l->error = NULL;
-	tinit(&l->vars, &l->area, 0);
-	tinit(&l->funs, &l->area, 0);
+	ktinit(&l->vars, &l->area, 0);
+	ktinit(&l->funs, &l->area, 0);
 	l->next = e->loc;
 	e->loc = l;
 }
@@ -100,9 +99,9 @@ initvar(void)
 	int i;
 	struct tbl *tp;
 
-	tinit(&specials, APERM, 32); /* must be 2^n (currently 17 specials) */
+	ktinit(&specials, APERM, 32); /* must be 2^n (currently 17 specials) */
 	for (i = 0; names[i].name; i++) {
-		tp = tenter(&specials, names[i].name, hash(names[i].name));
+		tp = ktenter(&specials, names[i].name, hash(names[i].name));
 		tp->flag = DEFINED|ISSET;
 		tp->type = names[i].v;
 	}
@@ -202,7 +201,7 @@ global(const char *n)
 		return vp;
 	}
 	for (l = e->loc; ; l = l->next) {
-		vp = tsearch(&l->vars, n, h);
+		vp = ktsearch(&l->vars, n, h);
 		if (vp != NULL) {
 			if (array)
 				return arraysearch(vp, val);
@@ -212,7 +211,7 @@ global(const char *n)
 		if (l->next == NULL)
 			break;
 	}
-	vp = tenter(&l->vars, n, h);
+	vp = ktenter(&l->vars, n, h);
 	if (array)
 		vp = arraysearch(vp, val);
 	vp->flag |= DEFINED;
@@ -243,12 +242,12 @@ local(const char *n, bool copy)
 		vp->areap = ATEMP;
 		return vp;
 	}
-	vp = tenter(&l->vars, n, h);
+	vp = ktenter(&l->vars, n, h);
 	if (copy && !(vp->flag & DEFINED)) {
 		struct block *ll = l;
 		struct tbl *vq = NULL;
 
-		while ((ll = ll->next) && !(vq = tsearch(&ll->vars, n, h)))
+		while ((ll = ll->next) && !(vq = ktsearch(&ll->vars, n, h)))
 			;
 		if (vq) {
 			vp->flag |= vq->flag &
@@ -282,7 +281,7 @@ str_val(struct tbl *vp)
 	else {				/* integer source */
 		/* worst case number length is when base=2, so use BITS(long) */
 		/* minus base #     number    null */
-		static char strbuf[1 + 2 + 1 + 8 * sizeof(long) + 1];
+		char strbuf[1 + 2 + 1 + 8 * sizeof(long) + 1];
 		const char *digits = (vp->flag & UCASEV_AL) ?
 		    "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ" :
 		    "0123456789abcdefghijklmnopqrstuvwxyz";
@@ -311,6 +310,8 @@ str_val(struct tbl *vp)
 			*--s = '-';
 		if (vp->flag & (RJUST|LJUST)) /* case already dealt with */
 			s = formatstr(vp, s);
+		else
+			s = str_save(s, ATEMP);
 	}
 	return s;
 }
@@ -419,6 +420,9 @@ getint(struct tbl *vp, long int *nump, bool arith)
 		if (*s == 'x' || *s == 'X') {
 			s++;
 			base = 16;
+		} else if (vp->flag & ZEROFIL) {
+			while (*s == '0')
+				s++;
 		} else
 			base = 8;
 		have_base++;
@@ -499,7 +503,7 @@ formatstr(struct tbl *vp, const char *s)
 		if (vp->flag & RJUST) {
 			const char *qq = s + olen;
 			/* strip trailing spaces (at&t uses qq[-1] == ' ') */
-			while (qq > s && isspace(qq[-1]))
+			while (qq > s && isspace((unsigned char)qq[-1]))
 				--qq;
 			slen = qq - s;
 			if (slen > vp->u2.field) {
@@ -512,7 +516,7 @@ formatstr(struct tbl *vp, const char *s)
 				vp->u2.field - slen, null, slen, s);
 		} else {
 			/* strip leading spaces/zeros */
-			while (isspace(*s))
+			while (isspace((unsigned char)*s))
 				s++;
 			if (vp->flag & ZEROFIL)
 				while (*s == '0')
@@ -525,11 +529,11 @@ formatstr(struct tbl *vp, const char *s)
 
 	if (vp->flag & UCASEV_AL) {
 		for (q = p; *q; q++)
-			if (islower(*q))
+			if (islower((unsigned char)*q))
 				*q = toupper(*q);
 	} else if (vp->flag & LCASEV) {
 		for (q = p; *q; q++)
-			if (isupper(*q))
+			if (isupper((unsigned char)*q))
 				*q = tolower(*q);
 	}
 
@@ -584,7 +588,7 @@ typeset(const char *var, Tflag set, Tflag clr, int field, int base)
 		/* IMPORT is only used when the shell starts up and is
 		 * setting up its environment.  Allow only simple array
 		 * references at this time since parameter/command substitution
-		 * is preformed on the [expression], which would be a major
+		 * is preformed on the [expression] which would be a major
 		 * security hole.
 		 */
 		if (set & IMPORT) {
@@ -617,8 +621,7 @@ typeset(const char *var, Tflag set, Tflag clr, int field, int base)
 	vpbase = (vp->flag & ARRAY) ? global(arrayname(var)) : vp;
 
 	/* only allow export flag to be set.  at&t ksh allows any attribute to
-	 * be changed, which means it can be truncated or modified
-	 * (-L/-R/-Z/-i).
+	 * be changed which means it can be truncated or modified (-L/-R/-Z/-i)
 	 */
 	if ((vpbase->flag&RDONLY) &&
 	    (val || clr || (set & ~EXPORT)))
@@ -827,7 +830,7 @@ makenv(void)
 
 				/* unexport any redefined instances */
 				for (l2 = l->next; l2 != NULL; l2 = l2->next) {
-					vp2 = tsearch(&l2->vars, vp->name, h);
+					vp2 = ktsearch(&l2->vars, vp->name, h);
 					if (vp2 != NULL)
 						vp2->flag &= ~EXPORT;
 				}
@@ -849,7 +852,9 @@ makenv(void)
  * Someone has set the srand() value, therefore from now on
  * we return values from rand() instead of arc4random()
  */
-int use_rand = !HAVE_ARC4RANDOM;
+#if HAVE_ARC4RANDOM
+int use_rand = 0;
+#endif
 
 /*
  * Called after a fork in parent to bump the random number generator.
@@ -859,7 +864,9 @@ int use_rand = !HAVE_ARC4RANDOM;
 void
 change_random(void)
 {
+#if HAVE_ARC4RANDOM
 	if (use_rand)
+#endif
 		rand();
 }
 
@@ -873,7 +880,7 @@ special(const char *name)
 {
 	struct tbl *tp;
 
-	tp = tsearch(&specials, name, hash(name));
+	tp = ktsearch(&specials, name, hash(name));
 	return tp && (tp->flag & ISSET) ? tp->type : V_NONE;
 }
 
@@ -883,9 +890,9 @@ unspecial(const char *name)
 {
 	struct tbl *tp;
 
-	tp = tsearch(&specials, name, hash(name));
+	tp = ktsearch(&specials, name, hash(name));
 	if (tp)
-		tdelete(tp);
+		ktdelete(tp);
 }
 
 static	time_t	seconds;		/* time SECONDS last set */
@@ -907,7 +914,9 @@ getspec(struct tbl *vp)
 		break;
 	case V_RANDOM:
 		vp->flag &= ~SPECIAL;
+#if HAVE_ARC4RANDOM
 		if (use_rand)
+#endif
 			setint(vp, (long) (rand() & 0x7fff));
 #if HAVE_ARC4RANDOM
 		else
@@ -986,9 +995,11 @@ setspec(struct tbl *vp)
 	case V_RANDOM:
 		vp->flag &= ~SPECIAL;
 		srand((unsigned int)intval(vp));
+#if HAVE_ARC4RANDOM
 		use_rand = 1;
-#if defined(__MirBSD__) && HAVE_ARC4RANDOM
+#if HAVE_ARC4RANDOM_PUSH
 		arc4random_push((unsigned)vp ^ (unsigned)rand());
+#endif
 #endif
 		vp->flag |= SPECIAL;
 		break;
@@ -1061,12 +1072,10 @@ arraysearch(struct tbl *vp, int val)
 	size_t namelen = strlen(vp->name) + 1;
 
 	vp->flag |= ARRAY|DEFINED;
-
+	vp->index = 0;
 	/* The table entry is always [0] */
-	if (val == 0) {
-		vp->index = 0;
+	if (val == 0)
 		return vp;
-	}
 	prev = vp;
 	curr = vp->u.array;
 	while (curr && curr->index < val) {
